@@ -27,11 +27,6 @@
 
 #include "goadaemon.h"
 
-#ifdef GOA_TELEPATHY_ENABLED
-#include "goatpaccountlinker.h"
-#endif
-
-
 /* ---------------------------------------------------------------------------------------------------- */
 
 static GMainLoop *loop = NULL;
@@ -45,10 +40,6 @@ static GOptionEntry opt_entries[] =
 };
 static GoaDaemon *the_daemon = NULL;
 
-#ifdef GOA_TELEPATHY_ENABLED
-static GoaTpAccountLinker *tp_linker = NULL;
-#endif
-
 static void
 on_bus_acquired (GDBusConnection *connection,
                  const gchar     *name,
@@ -74,10 +65,6 @@ on_name_acquired (GDBusConnection *connection,
                   gpointer         user_data)
 {
   g_debug ("Acquired the name %s on the session message bus", name);
-
-#ifdef GOA_TELEPATHY_ENABLED
-  tp_linker = goa_tp_account_linker_new ();
-#endif
 }
 
 static gboolean
@@ -144,9 +131,6 @@ main (int    argc,
 
  out:
   g_clear_object (&the_daemon);
-#ifdef GOA_TELEPATHY_ENABLED
-  g_clear_object (&tp_linker);
-#endif
   if (name_owner_id != 0)
     g_bus_unown_name (name_owner_id);
   g_clear_pointer (&loop, (GDestroyNotify) g_main_loop_unref);
