@@ -237,6 +237,23 @@ sign_in_identity (GoaKerberosProvider  *self,
   g_object_unref (operation_result);
 }
 
+static gchar *
+sign_in_identity_finish (GoaKerberosProvider  *self,
+                         GAsyncResult         *result,
+                         GError              **error)
+{
+  GTask *task;
+
+  g_return_val_if_fail (GOA_IS_KERBEROS_PROVIDER (self), NULL);
+
+  g_return_val_if_fail (g_task_is_valid (result, self), NULL);
+  task = G_TASK (result);
+
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  return g_task_propagate_pointer (task, error);
+}
+
 static void
 on_account_signed_in (GoaProvider   *provider,
                       GAsyncResult  *result,
@@ -335,7 +352,8 @@ get_ticket_sync (GoaKerberosProvider *self,
     }
 
   ret = TRUE;
-out:
+
+ out:
   g_clear_object (&account);
   g_clear_object (&ticketing);
   g_free (object_path);
@@ -821,7 +839,7 @@ on_initial_sign_in_done (GoaKerberosProvider *self,
                                                           "remember-password"));
 
   error = NULL;
-  object_path = g_task_propagate_pointer (G_TASK (result), &error);
+  object_path = sign_in_identity_finish (self, result, &error);
   if (error != NULL)
     {
       g_task_return_error (operation_result, error);
@@ -1417,7 +1435,7 @@ ensure_credentials_sync (GoaProvider    *provider,
   g_date_time_unref (now);
   g_date_time_unref (expiration_time);
 
-out:
+ out:
   g_clear_object (&account);
   g_clear_object (&identity);
   g_mutex_unlock (&identity_manager_mutex);
@@ -1599,7 +1617,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
                                                   error);
   g_mutex_unlock (&identity_manager_mutex);
 
-out:
+ out:
   g_object_unref (secret_exchange);
   return identity_object_path;
 }
@@ -1622,7 +1640,6 @@ sign_in_thread (GTask               *task,
 
   error = NULL;
   object_path = sign_in_identity_sync (self, identifier, password, preauth_source, cancellable, &error);
-
   if (object_path == NULL)
     g_task_return_error (task, error);
   else
